==> sight_21.1.1.orig.tar.gz: sight-21.1.1/libs/core/data/test/tu/PointTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2021-2022 IRCAD France
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::data
{

namespace ut
{

/**
 * This class is used to test data::Point
 */
class PointTest : public CPPUNIT_NS::TestFixture
{
private:

    CPPUNIT_TEST_SUITE(PointTest);
    CPPUNIT_TEST(copyTest);
    CPPUNIT_TEST(getterTest);
    CPPUNIT_TEST(setterTest);
    CPPUNIT_TEST(labelTest);
    CPPUNIT_TEST_SUITE_END();

public:

    /// Does nothing
    void setUp();
    void tearDown();

    /// Tests copies
    void copyTest();
    /// Tests getter
    void getterTest();
    ///Tests setter
    void setterTest();
    /// Tests labels of data::Point
    void labelTest();
};

} // namespace ut

} // namespace sight::data

==> sight_23.1.0.orig.tar.gz: sight-23.1.0/libs/core/data/test/tu/PointTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2021-2022 IRCAD France
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::data::ut
{

/**
 * This class is used to test data::Point
 */
class PointTest : public CPPUNIT_NS::TestFixture
{
private:

    CPPUNIT_TEST_SUITE(PointTest);
    CPPUNIT_TEST(copyTest);
    CPPUNIT_TEST(getterTest);
    CPPUNIT_TEST(setterTest);
    CPPUNIT_TEST(labelTest);
    CPPUNIT_TEST(equalityTest);
    CPPUNIT_TEST_SUITE_END();

public:

    /// Does nothing
    void setUp() override;
    void tearDown() override;

    /// Tests copies
    static void copyTest();
    /// Tests getter
    static void getterTest();
    ///Tests setter
    static void setterTest();
    /// Tests labels of data::Point
    static void labelTest();

    static void equalityTest();
};

} // namespace sight::data::ut
